ACT Example Gallery
===================

This gallery houses examples on different use cases for act including
downloading data from web APIs, visualization various types of data,
and more.  If there are specific use cases you would like to see examples
of, please head on over to the `ACT discussion page <https://github.com/ARM-DOE/ACT/discussions>`_ on GitHub.

If your looking to contribute, the templates directory found `here <https://arm-doe.github.io/ACT/source/auto_examples/templates/index.html>`_
provides templates for the examples gallery python files. For a template for
creating Jupyter notebooks for ACT tutorials, blog posts and more, that
template can be found `here <https://github.com/ARM-Development/ARM-Notebooks/blob/main/Templates/notebook-template.ipynb>`_
